/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005, 2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
package com.ibm.team.build.ant.task;

import java.io.File;
import java.util.List;

/**
 * Base ant task for publishing a file to an existing build result, using a file
 * (or directory) path as input. Ant tasks that need this behavior should
 * subclass this class. This class does not process the file or directory but it
 * does enforce that it exists. Subclasses must process the file or directory
 * and update the build result as appropriate.
 * <p>
 * <p>
 * Required attributes are:
 * <ul>
 * <li><b>filePath</b> - A path relative to the base directory of the build
 * file or the full path to the input file or directory.</li>
 * </ul>
 * <b>See {@link AbstractPublisherTask} for additional required and optional
 * attributes.</b>
 * 
 * @since 0.5
 */
public abstract class AbstractFilePublisherTask extends AbstractPublisherTask {

    /**
     * The ant attribute for this task in the ant script representing the path
     * to the input file or directory used during processing.
     */
    public static final String FILE_PATH = "filePath"; //$NON-NLS-1$

    private File fFilePath = null;

    /**
     * Retrieves the file representing the path to the input file or directory
     * used during task processing.
     * 
     * @return The file representing the path to the input file or directory
     *         used during task processing.
     */
    protected File getFile() {
        return fFilePath;
    }

    /**
     * Sets the file representing the path to the input file or directory used
     * during task processing.
     * 
     * @param filePath
     *            The file representing the path to the input file or directory
     *            used during task processing.
     */
    public void setFilePath(File filePath) {
        fFilePath = filePath;
    }

    /*
     * (non-Javadoc) Intentionally not documented. See parent.
     */
    protected void collectAntAttributes(List antAttributes) {
        super.collectAntAttributes(antAttributes);
        antAttributes.add(new FileAntAttribute(FILE_PATH, fFilePath, true, true));
    }

}
