/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007, 2010. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/

package com.ibm.team.build.internal.parser.data;


/**
 * Base class for <code>problem</code> and <code>error</code> elements in a
 * JUnit log file.
 */
public abstract class AbstractJUnitParserProblemData {

    /**
     * The problem <code>type</code>.
     */
    private String fProblemType;

    /**
     * The problem <code>message</code>.
     */
    private String fProblemMessage;

    /**
     * The problem stack trace.
     */
    private String fStackTrace;

    /**
     * Constructs a problem data instance with the attributes of a problem
     * element.
     * 
     * @param type
     *            value of the type attribute of the <code>problem</code>
     *            element, or <code>null</code>.
     * @param message
     *            value of the message attribute of the <code>problem</code>
     *            element, or <code>null</code>.
     */
    protected AbstractJUnitParserProblemData(String type, String message) {
        fProblemType = type;
        fProblemMessage = message;
    }

    /**
     * Allow access to the problem type.
     * 
     * @return the problem type
     */
    public String getType() {
        return fProblemType;
    }

    /**
     * Allow access to the problem message.
     * 
     * @return the problem message
     */
    public String getMessage() {
        return fProblemMessage;
    }

    /**
     * Allow access to the problem stack trace.
     * 
     * @return the problem stack trace.
     */
    public String getStackTrace() {
        /*
         * For reasons still unknown, sometimes the "<className>: <message>"
         * header portion of the stack trace seems to be filtered out by the
         * JUnitXMLResultFormatter. So we check for that here and put it back in
         * if it's missing.
         */
        String stackTrace = fStackTrace;
        if (stackTrace == null) {
            stackTrace = ""; //$NON-NLS-1$
        }
        
        if (fProblemType != null && fProblemType.length() > 0 && !stackTrace.startsWith(fProblemType)) {
                return ((fProblemMessage != null) ? (fProblemType + ": " + fProblemMessage) : fProblemType) + "\n" + stackTrace; //$NON-NLS-1$ //$NON-NLS-2$
        }

        return stackTrace;
    }

    /**
     * Set the problem stack trace.
     * 
     * @param stackTrace
     *            the problem stack trace.
     */
    public void setStackTrace(String stackTrace) {
        fStackTrace = stackTrace;
    }

}
