/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005, 2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
package com.ibm.team.build.internal.publishing;

import java.io.File;

import com.ibm.team.build.common.model.IBuildResultContribution;
import com.ibm.team.repository.client.ITeamRepository;
import com.ibm.team.repository.common.IContent;
import com.ibm.team.repository.common.TeamRepositoryException;

/**
 * Base class for publishers that add file contents to a build result
 * contribution.
 */
public abstract class AbstractFilePublisher extends AbstractContributionPublisher {
    /**
     * The location of the file associated with the contribution to be published
     */
    private final String fFileLocation;

    /**
     * Create a file publisher object.
     * 
     * @param extendedContributionTypeId
     *            the extended contribution type id to associate with the file
     *            contribution being published by this object
     * @param fileLocation
     *            the location of the file associated with the file contribution
     *            being published by this object
     * @param label
     *            the label describing the file contribution to be published by
     *            this object
     */
    public AbstractFilePublisher(String extendedContributionTypeId, String fileLocation, String label) {
        super(extendedContributionTypeId, label);
        fFileLocation = fileLocation;
    }

    protected void initializeContribution(IBuildResultContribution contribution, ITeamRepository teamRepository)
            throws TeamRepositoryException {

        contribution.setExtendedContributionData(getFileContent(teamRepository));
        contribution.setExtendedContributionProperty(IBuildResultContribution.PROPERTY_NAME_FILE_NAME, new File(
                fFileLocation).getName());
    }
    
    protected String getFilePath() {
        return fFileLocation;
    }

    /**
     * Get the file content.
     * 
     * @param fileLocation
     *            The file location.
     * @param teamRepository
     *            The repository to use.
     * @return A content object for the file.
     * @throws TeamRepositoryException
     */
    protected abstract IContent getFileContent(ITeamRepository teamRepository)
            throws TeamRepositoryException;

}
