/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005, 2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
package com.ibm.team.build.internal.publishing;

import com.ibm.team.build.common.model.IBuildResultContribution;

/**
 * Adds an artifact-type contribution containing content (the artifact is stored
 * in the repository) to an existing build result.
 */
public class ArtifactFilePublisher extends ContentPublisher {

    /**
     * Create an ArtifactPublisher object.
     * <p>
     * The content type will be determined from the filename extension. If the
     * extension is unknown, the type defaults to "application/unknown".
     * <p>
     * If the content type resolves to text, the character encoding is assumed
     * to be the platform default encoding.
     * 
     * @param fileLocation
     *            the location of the file associated with the file contribution
     *            being published by this object
     * @param label
     *            the label describing the file contribution to be published by
     *            this object
     */
    public ArtifactFilePublisher(String fileLocation, String label) {
        super(IBuildResultContribution.ARTIFACT_EXTENDED_CONTRIBUTION_ID, fileLocation, label, null, null);
    }

    /**
     * Create an ArtifactPublisher object. Caller supplies the content type and
     * character encoding used when writing the artifact to the repository
     * <p>
     * If content type is not specified, the type will be determined from the
     * filename extension. If the extension is unknown, the type defaults to
     * "application/unknown".
     * <p>
     * If the content type resolves to text and the character encoding is not
     * specified it is assumed to be the platform default encoding.
     * 
     * @param fileLocation
     *            the location of the file associated with the file contribution
     *            being published by this object
     * @param label
     *            the label describing the file contribution to be published by
     *            this object
     * @param contentType
     *            The content type of the artifact (optional)
     * @param characterEncoding
     *            The character encoding of the artifact (optional)
     */
    public ArtifactFilePublisher(String fileLocation, String label, String contentType, String characterEncoding) {
        super(IBuildResultContribution.ARTIFACT_EXTENDED_CONTRIBUTION_ID, fileLocation, label, contentType,
                characterEncoding);
    }

}
