/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005, 2007. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
package com.ibm.team.build.internal.publishing;

import com.ibm.team.build.common.model.IBuildResultContribution;
import com.ibm.team.repository.client.ITeamRepository;
import com.ibm.team.repository.common.TeamRepositoryException;

/**
 * Adds a link contribution to an existing build result.
 */
public class LinkPublisher extends AbstractContributionPublisher {

    private final String fUrl;

    /**
     * Create a link publisher object.
     * 
     * @param url
     *            the url being published
     * @param label
     *            the label describing the file contribution to be published by
     *            this object
     */
    public LinkPublisher(String url, String label) {
        this(IBuildResultContribution.LINK_EXTENDED_CONTRIBUTION_ID, url, label);
    }

    /**
     * Create a link publisher object using a custom extended contribution type
     * id.
     * 
     * @param extendedContributionTypeId
     *            The extended contribution type id to use.
     * @param url
     *            the url being published
     * @param label
     *            the label describing the file contribution to be published by
     *            this object
     */
    public LinkPublisher(String extendedContributionTypeId, String url, String label) {
        super(extendedContributionTypeId, label);
        fUrl = url;
    }

    protected void initializeContribution(IBuildResultContribution contribution, ITeamRepository teamRepository)
            throws TeamRepositoryException {
        contribution.setExtendedContributionProperty(IBuildResultContribution.PROPERTY_NAME_URL, fUrl);
    }
}
