/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2011. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
package com.ibm.team.build.internal.publishing;

import com.ibm.team.build.common.model.IBuildResultContribution;
import com.ibm.team.repository.client.ITeamRepository;
import com.ibm.team.repository.common.TeamRepositoryException;

/**
 * Adds a log-type contribution containing a URL link (pointing at an
 * log outside the repository) to an existing build result.
 */
public class LogLinkPublisher extends LinkPublisher {

    private long fLinkSize;

    /**
     * Create an LogLinkPublisher object.
     * 
     * @param url
     *            the url being published in this contribution
     * @param label
     *            the label describing the contribution to be published
     */
    public LogLinkPublisher(String url, String label) {
        super(IBuildResultContribution.LOG_EXTENDED_CONTRIBUTION_ID, url, label);
    }

    /**
     * Set the size of the file referenced by the link. This will be stored in
     * the contribution.
     * 
     * @param linkSize
     *            The size of the link file in bytes.
     */
    public void setLinkSize(long linkSize) {
        fLinkSize = linkSize;
    }

    protected void initializeContribution(IBuildResultContribution contribution, ITeamRepository teamRepository)
            throws TeamRepositoryException {
        super.initializeContribution(contribution, teamRepository);
        if (fLinkSize != 0) {
            contribution.setExtendedContributionProperty(IBuildResultContribution.PROPERTY_NAME_FILE_SIZE,
                    Long.toString(fLinkSize));
        }
    }
}
