/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005, 2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
package com.ibm.team.build.internal.publishing;

import com.ibm.team.build.common.model.IBuildResultContribution;
import com.ibm.team.repository.common.IContent;

/**
 * Adds a log-type contribution to an existing build result. Files published
 * with this publisher are assumed to contain text unless a different content
 * type is specified.
 * <p>
 * Files with a text mime-type published with this publisher are converted from
 * their original character encoding to UTF-8 when they are stored in the
 * repository.
 */
public class LogPublisher extends ContentPublisher {

    /**
     * Create a LogPublisher object.
     * <p>
     * The content type will be determined from the filename extension. If the
     * extension is unknown, the type defaults to "text/plain".
     * <p>
     * If character encoding is not specified, it is assumed to be the platform
     * default encoding.
     * 
     * @param fileLocation
     *            the location of the file associated with the file contribution
     *            being published by this object
     * @param label
     *            the label describing the file contribution to be published by
     *            this object
     */
    public LogPublisher(String fileLocation, String label) {
        super(IBuildResultContribution.LOG_EXTENDED_CONTRIBUTION_ID, fileLocation, label, null, null);
    }

    /**
     * Create a LogPublisher object. Caller supplies an optional content type
     * and character encoding for the log file.
     * <p>
     * If content type is not specified, the type will be determined from the
     * filename extension. If the extension is unknown, the type defaults to
     * "text/plain".
     * <p>
     * If character encoding is not specified, it is assumed to be the platform
     * default encoding.
     * 
     * @param fileLocation
     *            the location of the file associated with the file contribution
     *            being published by this object
     * @param label
     *            the label describing the file contribution to be published by
     *            this object
     * @param contentType
     *            The content type of the log file data (optional)
     * @param characterEncoding
     *            The character encoding of the log file (optional)
     */
    public LogPublisher(String fileLocation, String label, String contentType, String characterEncoding) {
        super(IBuildResultContribution.LOG_EXTENDED_CONTRIBUTION_ID, fileLocation, label, contentType,
                characterEncoding);
    }

    @Override
    public String getDefaultContentType() {
        return IContent.CONTENT_TYPE_TEXT;
    }
}
