/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007, 2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/

package com.ibm.team.build.internal.publishing.workitem;

import com.ibm.team.workitem.common.model.IWorkItemHandle;

/**
 * Status returned from publishing work items.
 */
public class WorkItemPublishStatus {

    /**
     * Constant that indicates that the number of work items was not known
     * before the publisher ran. This happens if the publisher is finding change
     * sets from the TeamAcceptTask rather than work item ids in a file.
     */
    public static int NUMBER_OF_WORKITEMS_UNKNOWN = -1;

    private IWorkItemHandle[] fWorkItemHandles;
    private int fExpectedWorkItemCount;

    /**
     * Create a new status object.
     * 
     * @param workItemHandles
     *            Handles of the work items that were published.
     * @param expectedWorkItemsCount
     *            The number of work items that were expected to be published.
     * 
     */
    public WorkItemPublishStatus(IWorkItemHandle[] workItemHandles, int expectedWorkItemsCount) {
        fWorkItemHandles = workItemHandles;
        fExpectedWorkItemCount = expectedWorkItemsCount;
    }

    /**
     * Create a new status object.that indicates that there were no work items
     * with ids that could not be found.
     * 
     * @param workItemHandles
     *            Handles of the work items that were published.
     */
    public WorkItemPublishStatus(IWorkItemHandle[] workItemHandles) {
        fWorkItemHandles = workItemHandles;
        fExpectedWorkItemCount = NUMBER_OF_WORKITEMS_UNKNOWN;
    }

    /**
     * Allows access to the handles of the work items published.
     * @return the workItemHandles.
     */
    public IWorkItemHandle[] getWorkItemHandles() {
        return fWorkItemHandles;
    }

    /**
     * Allows access to the expected number of work item ids. If there was no
     * way to know how many work items might be found, this number is set to
     * {@link #NUMBER_OF_WORKITEMS_UNKNOWN}.
     * 
     * @return the number of work items in the file passed to the
     *         <code>WorkItemPublisher</code> or
     *         {@link #NUMBER_OF_WORKITEMS_UNKNOWN} if the file did not contain
     *         work item ids.
     */
    public int getNumberOfWorkItemsExpected() {
        return fExpectedWorkItemCount;
    }

}
