/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/

package com.ibm.team.build.internal.scm;

import com.ibm.team.scm.common.IComponentHandle;
import com.ibm.team.scm.common.IFolderHandle;

/**
 * Utility class for representing a folder entry.
 */
public class FolderEntry {
    /**
     * The folder handle
     */
    private final IFolderHandle fFolderHandle;

    /**
     * The component handle
     */
    private final IComponentHandle fComponentHandle;

    /**
     * The folderName
     */
    private final String fFolderName;

    /**
     * Create the folder entry.
     * 
     * @param folderHandle
     *            The folder handle.
     * @param componentHandle
     *            The component handle.
     * @param folderName
     *            The folder name.
     */
    public FolderEntry(IFolderHandle folderHandle, IComponentHandle componentHandle, String folderName) {
        fFolderHandle = folderHandle;
        fComponentHandle = componentHandle;
        fFolderName = folderName;
    }

    /**
     * Get the folder handle.
     * 
     * @return the folder handle
     */
    public IFolderHandle getFolderHandle() {
        return fFolderHandle;
    }

    /**
     * Get the component handle.
     * 
     * @return the component handle
     */
    public IComponentHandle getComponentHandle() {
        return fComponentHandle;
    }

    /**
     * Get the folder name.
     * 
     * @return the folder name
     */
    public String getFolderName() {
        return fFolderName;
    }

    /*
     * (non-Javadoc) Intentionally not documented. See parent.
     */
    @Override
    public int hashCode() {
        return fFolderHandle.getItemId().hashCode();
    }

    /*
     * (non-Javadoc) Intentionally not documented. See parent.
     */
    @Override
    public boolean equals(Object o) {
        if (!(o instanceof FolderEntry)) {
            return false;
        }
        if (o == this) {
            return true;
        }
        FolderEntry other = (FolderEntry) o;
        return other.fComponentHandle.sameItemId(fComponentHandle) && other.fFolderHandle.sameItemId(fFolderHandle);
    }

}
